@@ -41,9 +41,9 @@ typedef struct term_s        term_t;
 typedef struct toggle_s      toggle_t;
 typedef struct win_s         win_t;
 typedef struct word_s        word_t;
-typedef struct attr_s        attr_t;
-typedef struct limits_s      limits_t;
-typedef struct timers_s      timers_t;
+typedef struct attrib_s      attrib_t;
+typedef struct limit_s       limit_t;
+typedef struct ticker_s      ticker_t;
 typedef struct misc_s        misc_t;
 typedef struct sed_s         sed_t;
 typedef struct timeout_s     timeout_t;
@@ -165,7 +165,7 @@ struct toggle_s
 
 /* Structure to store the default or imposed smenu limits */
 /* """""""""""""""""""""""""""""""""""""""""""""""""""""" */
-struct limits_s
+struct limit_s
 {
   long word_length; /* maximum number of bytes in a word */
   long words;       /* maximum number of words           */
@@ -174,7 +174,7 @@ struct limits_s
 
 /* Structure to store the default or imposed timers */
 /* """""""""""""""""""""""""""""""""""""""""""""""" */
-struct timers_s
+struct ticker_s
 {
   int search;
   int help;
@@ -188,6 +188,7 @@ struct misc_s
 {
   search_mode_t default_search_method;
   char          invalid_char_substitute;
+  int           ignore_quotes;
 };
 
 /* Terminal setting variables */
@@ -206,7 +207,7 @@ int search_timer  = -1;
 
 /* Structure containing the attributes components */
 /* """""""""""""""""""""""""""""""""""""""""""""" */
-struct attr_s
+struct attrib_s
 {
   attr_set_t  is_set;
   short       fg;
@@ -266,7 +267,7 @@ struct word_s
   char *        orig;          /* NULL or original string if is had been   *
                                 * shortened for being displayed or altered *
                                 * by is expansion.                         */
-  char *        bitmap;        /* used to store the the position of the    *
+  char *        bitmap;        /* used to store the position of the        *
                                 * currently searched chars in a word. The  *
                                 * objective is to speed their display      */
   unsigned char is_matching;
@@ -305,24 +306,24 @@ struct win_s
   unsigned char wide;      /* -w */
   unsigned char center;    /* -M */
 
-  attr_t cursor_attr;           /* current cursor attributes          */
-  attr_t cursor_on_tag_attr;    /* current cursor on tag attributes   */
-  attr_t bar_attr;              /* scrollbar attributes               */
-  attr_t shift_attr;            /* shift indicator attributes         */
-  attr_t message_attr;          /* message (title) attributes         */
-  attr_t search_field_attr;     /* search mode field attributes       */
-  attr_t search_text_attr;      /* search mode text attributes        */
-  attr_t search_err_field_attr; /* bad search mode field attributes   */
-  attr_t search_err_text_attr;  /* bad search mode text attributes    */
-  attr_t match_field_attr;      /* matching word field attributes     */
-  attr_t match_text_attr;       /* matching word text attributes      */
-  attr_t match_err_field_attr;  /* bad matching word field attributes */
-  attr_t match_err_text_attr;   /* bad matching word text attributes  */
-  attr_t include_attr;          /* selectable words attributes        */
-  attr_t exclude_attr;          /* non-selectable words attributes    */
-  attr_t tag_attr;              /* non-selectable words attributes    */
-  attr_t daccess_attr;          /* direct access tag attributes       */
-  attr_t special_attr[5];       /* special (-1,...) words attributes  */
+  attrib_t cursor_attr;           /* current cursor attributes          */
+  attrib_t cursor_on_tag_attr;    /* current cursor on tag attributes   */
+  attrib_t bar_attr;              /* scrollbar attributes               */
+  attrib_t shift_attr;            /* shift indicator attributes         */
+  attrib_t message_attr;          /* message (title) attributes         */
+  attrib_t search_field_attr;     /* search mode field attributes       */
+  attrib_t search_text_attr;      /* search mode text attributes        */
+  attrib_t search_err_field_attr; /* bad search mode field attributes   */
+  attrib_t search_err_text_attr;  /* bad search mode text attributes    */
+  attrib_t match_field_attr;      /* matching word field attributes     */
+  attrib_t match_text_attr;       /* matching word text attributes      */
+  attrib_t match_err_field_attr;  /* bad matching word field attributes */
+  attrib_t match_err_text_attr;   /* bad matching word text attributes  */
+  attrib_t include_attr;          /* selectable words attributes        */
+  attrib_t exclude_attr;          /* non-selectable words attributes    */
+  attrib_t tag_attr;              /* non-selectable words attributes    */
+  attrib_t daccess_attr;          /* direct access tag attributes       */
+  attrib_t special_attr[5];       /* special (-1,...) words attributes  */
 };
 
 /* Sed like node structure */
@@ -358,8 +359,8 @@ struct output_s
   char * output_str; /* The pinned word itself                               */
 };
 
-/* Structure describing the formating of the automatic direct access entries */
-/* """"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""" */
+/* Structure describing the formatting of the automatic direct access entries */
+/* """""""""""""""""""""""""""""""'"""""""""""""""""""""""""""""""""""""""""" */
 struct daccess_s
 {
   da_mode_t mode; /* DA_TYPE_NONE (0), DA_TYPE_AUTO, DA_TYPE_POS          */
@@ -371,7 +372,7 @@ struct daccess_s
   char   padding;    /* a: all; i: only included words are padded         */
   char   head;       /* What to do with chars before the embedded number  */
   int    length;     /* selector size (5 max)                             */
-  int    flength;    /* 0 or length + 3 (full prefix lengh                */
+  int    flength;    /* 0 or length + 3 (full prefix length               */
   size_t offset;     /* offset to the start of the selector               */
   char   missing;    /* y: number missing embedded numbers                */
   int    plus;       /* 1 if we can look for the number to extract after  *
@@ -409,7 +410,7 @@ struct search_data_s
 /* ********** */
 
 void
-help(win_t * win, term_t * term, long last_line, toggle_t * toggle);
+help(win_t * win, term_t * term, long last_line, toggle_t * toggles);
 
 int
 tag_comp(void * a, void * b);
@@ -421,13 +422,13 @@ int
 isempty(const char * s);
 
 void
-my_beep(toggle_t * toggle);
+my_beep(toggle_t * toggles);
 
 int
 get_cursor_position(int * const r, int * const c);
 
 void
-get_terminal_size(int * const r, int * const c);
+get_terminal_size(int * const r, int * const c, term_t * term);
 
 int
 #ifdef __sun
@@ -443,7 +444,7 @@ void
 setup_term(int const fd);
 
 void
-strip_ansi_color(char * s, toggle_t * toggle, misc_t * misc);
+strip_ansi_color(char * s, toggle_t * toggles, misc_t * misc);
 
 int
 tst_cb(void * elem);
@@ -452,20 +453,23 @@ int
 tst_cb_cli(void * elem);
 
 int
-ini_load(const char * filename, win_t * win, term_t * term, limits_t * limits,
-         timers_t * timers, misc_t * misc, langinfo_t * langinfo,
-         int (*report)(win_t * win, term_t * term, limits_t * limits,
-                       timers_t * timers, misc_t * misc, langinfo_t * langinfo,
+ini_load(const char * filename, win_t * win, term_t * term, limit_t * limits,
+         ticker_t * timers, misc_t * misc, langinfo_t * langinfo,
+         int (*report)(win_t * win, term_t * term, limit_t * limits,
+                       ticker_t * timers, misc_t * misc, langinfo_t * langinfo,
                        const char * section, const char * name, char * value));
 
 int
-ini_cb(win_t * win, term_t * term, limits_t * limits, timers_t * timers,
+ini_cb(win_t * win, term_t * term, limit_t * limits, ticker_t * timers,
        misc_t * misc, langinfo_t * langinfo, const char * section,
        const char * name, char * value);
 
 char *
 make_ini_path(char * name, char * base);
 
+short
+color_transcode(short color);
+
 void
 set_foreground_color(term_t * term, short color);
 
@@ -479,7 +483,7 @@ long
 build_metadata(term_t * term, long count, win_t * win);
 
 long
-disp_lines(win_t * win, toggle_t * toggle, long current, long count,
+disp_lines(win_t * win, toggle_t * toggles, long current, long count,
            search_mode_t search_mode, search_data_t * search_data,
            term_t * term, long last_line, char * tmp_word,
            langinfo_t * langinfo);
@@ -490,7 +494,7 @@ get_message_lines(char * message, ll_t * message_lines_list,
 
 void
 disp_message(ll_t * message_lines_list, long width, long max_len, term_t * term,
-             win_t * win);
+             win_t * win, langinfo_t * langinfo);
 
 int
 check_integer_constraint(int nb_args, char ** args, char * value, char * par);
@@ -520,7 +524,7 @@ disp_word(long pos, search_mode_t search_mode, search_data_t * search_data,
           term_t * term, win_t * win, char * tmp_word);
 
 size_t
-expand(char * src, char * dest, langinfo_t * langinfo, toggle_t * toggle,
+expand(char * src, char * dest, langinfo_t * langinfo, toggle_t * toggles,
        misc_t * misc);
 
 int
@@ -533,8 +537,8 @@ get_scancode(unsigned char * s, size_t max);
 char *
 get_word(FILE * input, ll_t * word_delims_list, ll_t * record_delims_list,
          ll_t * ignored_glyphs_list, char * utf8_buffer,
-         unsigned char * is_last, toggle_t * toggle, langinfo_t * langinfo,
-         win_t * win, limits_t * limits, misc_t * misc);
+         unsigned char * is_last, toggle_t * toggles, langinfo_t * langinfo,
+         win_t * win, limit_t * limits, misc_t * misc);
 
 void
 left_margin_putp(char * s, term_t * term, win_t * win);
@@ -562,13 +566,13 @@ int
 replace(char * orig, sed_t * sed);
 
 int
-decode_attr_toggles(char * s, attr_t * attr);
+decode_attr_toggles(char * s, attrib_t * attr);
 
 int
-parse_attr(char * str, attr_t * attr, short max_color);
+parse_attr(char * str, attrib_t * attr, short max_color);
 
 void
-apply_attr(term_t * term, attr_t attr);
+apply_attr(term_t * term, attrib_t attr);
 
 int
 delims_cmp(const void * a, const void * b);
@@ -577,12 +581,12 @@ long
 get_line_last_word(long line, long last_line);
 
 void
-move_left(win_t * win, term_t * term, toggle_t * toggle,
+move_left(win_t * win, term_t * term, toggle_t * toggles,
           search_data_t * search_data, langinfo_t * langinfo, long * nl,
           long last_line, char * tmp_word);
 
 void
-move_right(win_t * win, term_t * term, toggle_t * toggle,
+move_right(win_t * win, term_t * term, toggle_t * toggles,
            search_data_t * search_data, langinfo_t * langinfo, long * nl,
            long last_line, char * tmp_word);
 
@@ -593,13 +597,17 @@ int
 find_best_word_downward(long last_word, long s, long e);
 
 void
-move_up(win_t * win, term_t * term, toggle_t * toggle,
+move_up(win_t * win, term_t * term, toggle_t * toggles,
         search_data_t * search_data, langinfo_t * langinfo, long * nl,
         long page, long first_selectable, long last_line, char * tmp_word);
 
 void
-move_down(win_t * win, term_t * term, toggle_t * toggle,
+move_down(win_t * win, term_t * term, toggle_t * toggles,
           search_data_t * search_data, langinfo_t * langinfo, long * nl,
           long page, long last_selectable, long last_line, char * tmp_word);
 
+void
+init_main_ds(attrib_t * init_attr, win_t * win, limit_t * limits,
+             ticker_t * timers, toggle_t * toggles, misc_t * misc,
+             timeout_t * timeout, daccess_t * daccess);
 #endif
