@@ -6,6 +6,9 @@
 #ifndef UTILS_H
 #define UTILS_H
 
+# include <errno.h>
+# include <unistd.h>
+
 typedef struct interval_s interval_t;
 typedef struct range_s    range_t;
 
