@@ -1,6 +1,12 @@
 #ifndef XMALLOC_H
 #define XMALLOC_H
 
+void *
+rpl_malloc(size_t size);
+
+void *
+rpl_realloc(void * ptr, size_t size);
+
 void *
 xmalloc(size_t size);
 
